/* properties.c generated by valac 0.30.0.37-86f3c, the Vala compiler
 * generated from properties.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <gdk/gdk.h>
#include <glib/gi18n-lib.h>
#include <libgd/gd.h>


#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;
typedef struct _BoxesPropertiesPrivate BoxesPropertiesPrivate;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_PROPERTIES_PAGE_WIDGET (boxes_properties_page_widget_get_type ())
#define BOXES_PROPERTIES_PAGE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_PAGE_WIDGET, BoxesPropertiesPageWidget))
#define BOXES_PROPERTIES_PAGE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_PAGE_WIDGET, BoxesPropertiesPageWidgetClass))
#define BOXES_IS_PROPERTIES_PAGE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_PAGE_WIDGET))
#define BOXES_IS_PROPERTIES_PAGE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_PAGE_WIDGET))
#define BOXES_PROPERTIES_PAGE_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_PAGE_WIDGET, BoxesPropertiesPageWidgetClass))

typedef struct _BoxesPropertiesPageWidget BoxesPropertiesPageWidget;
typedef struct _BoxesPropertiesPageWidgetClass BoxesPropertiesPageWidgetClass;
typedef struct _BoxesPropertiesPageWidgetPrivate BoxesPropertiesPageWidgetPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))

#define BOXES_TYPE_PROPERTIES_WINDOW (boxes_properties_window_get_type ())
#define BOXES_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindow))
#define BOXES_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))
#define BOXES_IS_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_IS_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_PROPERTIES_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))

typedef struct _BoxesPropertiesWindow BoxesPropertiesWindow;
typedef struct _BoxesPropertiesWindowClass BoxesPropertiesWindowClass;
typedef struct _Block73Data Block73Data;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesProperties {
	GtkNotebook parent_instance;
	BoxesPropertiesPrivate * priv;
};

struct _BoxesPropertiesClass {
	GtkNotebookClass parent_class;
};

struct _BoxesPropertiesPrivate {
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
	BoxesAppWindow* window;
	gulong stats_id;
	gboolean restore_fullscreen;
};

struct _BoxesPropertiesPageWidget {
	GtkBox parent_instance;
	BoxesPropertiesPageWidgetPrivate * priv;
	gboolean empty;
};

struct _BoxesPropertiesPageWidgetClass {
	GtkBoxClass parent_class;
};

struct _Block73Data {
	int _ref_count_;
	BoxesProperties* self;
	BoxesMachine* machine;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

typedef void (*BoxesNotificationOKFunc) (void* user_data);
typedef void (*BoxesNotificationCancelFunc) (void* user_data);

static gpointer boxes_properties_parent_class = NULL;
static BoxesUIIface* boxes_properties_boxes_ui_parent_iface = NULL;

GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
#define BOXES_PROPERTIES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_PROPERTIES, BoxesPropertiesPrivate))
enum  {
	BOXES_PROPERTIES_DUMMY_PROPERTY,
	BOXES_PROPERTIES_PREVIOUS_UI_STATE,
	BOXES_PROPERTIES_UI_STATE
};
static void boxes_properties_populate (BoxesProperties* self);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
BoxesCollectionItem* boxes_app_window_get_current_item (BoxesAppWindow* self);
GType boxes_properties_page_widget_get_type (void) G_GNUC_CONST;
BoxesPropertiesPageWidget* boxes_properties_page_widget_new (BoxesPropertiesPage page, BoxesMachine* machine);
BoxesPropertiesPageWidget* boxes_properties_page_widget_construct (GType object_type, BoxesPropertiesPage page, BoxesMachine* machine);
static void _____lambda90_ (BoxesProperties* self);
static void ______lambda90__boxes_properties_page_widget_refresh_properties (BoxesPropertiesPageWidget* _sender, gpointer self);
GType boxes_properties_window_get_type (void) G_GNUC_CONST;
void boxes_properties_setup_ui (BoxesProperties* self, BoxesAppWindow* window, BoxesPropertiesWindow* dialog);
static gboolean boxes_properties_on_key_pressed (BoxesProperties* self, GtkWidget* widget, GdkEventKey* event);
static gboolean _boxes_properties_on_key_pressed_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self);
static void boxes_properties_ui_state_changed (BoxesProperties* self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
gboolean boxes_app_window_get_fullscreened (BoxesAppWindow* self);
void boxes_app_window_set_fullscreened (BoxesAppWindow* self, gboolean value);
static Block73Data* block73_data_ref (Block73Data* _data73_);
static void block73_data_unref (void * _userdata_);
gboolean boxes_properties_page_widget_flush_changes (BoxesPropertiesPageWidget* self);
gboolean boxes_machine_get_is_on (BoxesMachine* self);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
BoxesNotificationbar* boxes_app_window_get_notificationbar (BoxesAppWindow* self);
GdNotification* boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationCancelFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify, gint timeout);
static void _____lambda91_ (Block73Data* _data73_);
void boxes_machine_restart (BoxesMachine* self);
static void ______lambda91__boxes_notification_ok_func (gpointer self);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
BoxesProperties* boxes_properties_new (void);
BoxesProperties* boxes_properties_construct (GType object_type);
static GObject * boxes_properties_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_properties_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_properties_finalize (GObject* obj);
static void _vala_boxes_properties_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_properties_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


GType boxes_properties_page_get_type (void) {
	static volatile gsize boxes_properties_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_PROPERTIES_PAGE_GENERAL, "BOXES_PROPERTIES_PAGE_GENERAL", "general"}, {BOXES_PROPERTIES_PAGE_SYSTEM, "BOXES_PROPERTIES_PAGE_SYSTEM", "system"}, {BOXES_PROPERTIES_PAGE_DEVICES, "BOXES_PROPERTIES_PAGE_DEVICES", "devices"}, {BOXES_PROPERTIES_PAGE_SNAPSHOTS, "BOXES_PROPERTIES_PAGE_SNAPSHOTS", "snapshots"}, {BOXES_PROPERTIES_PAGE_LAST, "BOXES_PROPERTIES_PAGE_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_properties_page_type_id;
		boxes_properties_page_type_id = g_enum_register_static ("BoxesPropertiesPage", values);
		g_once_init_leave (&boxes_properties_page_type_id__volatile, boxes_properties_page_type_id);
	}
	return boxes_properties_page_type_id__volatile;
}


static gpointer _g_object_ref0 (gpointer self) {
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return self ? g_object_ref (self) : NULL;
#line 250 "properties.c"
}


static void _____lambda90_ (BoxesProperties* self) {
	gint current_page = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_get ((GtkNotebook*) self, "page", &_tmp0_, NULL);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp1_ = _tmp0_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	current_page = _tmp1_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_populate (self);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_set ((GtkNotebook*) self, "page", current_page, NULL);
#line 268 "properties.c"
}


static void ______lambda90__boxes_properties_page_widget_refresh_properties (BoxesPropertiesPageWidget* _sender, gpointer self) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_____lambda90_ ((BoxesProperties*) self);
#line 275 "properties.c"
}


static void boxes_properties_populate (BoxesProperties* self) {
	GList* _tmp0_ = NULL;
	BoxesMachine* machine = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesCollectionItem* _tmp3_ = NULL;
	BoxesCollectionItem* _tmp4_ = NULL;
	BoxesMachine* _tmp5_ = NULL;
	BoxesMachine* _tmp6_ = NULL;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = gtk_container_get_children ((GtkContainer*) self);
#line 291 "properties.c"
	{
		GList* page_collection = NULL;
		GList* page_it = NULL;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		page_collection = _tmp0_;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		for (page_it = page_collection; page_it != NULL; page_it = page_it->next) {
#line 299 "properties.c"
			GtkWidget* page = NULL;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			page = (GtkWidget*) page_it->data;
#line 303 "properties.c"
			{
				GtkWidget* _tmp1_ = NULL;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp1_ = page;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				gtk_container_remove ((GtkContainer*) self, _tmp1_);
#line 310 "properties.c"
			}
		}
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_list_free0 (page_collection);
#line 315 "properties.c"
	}
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = self->priv->window;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = boxes_app_window_get_current_item (_tmp2_);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4_ = _tmp3_;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp4_) : NULL);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	machine = _tmp5_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = machine;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp6_ == NULL) {
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (machine);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		return;
#line 335 "properties.c"
	}
	{
		gint i = 0;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		i = 0;
#line 341 "properties.c"
		{
			gboolean _tmp7_ = FALSE;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp7_ = TRUE;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			while (TRUE) {
#line 348 "properties.c"
				gint _tmp9_ = 0;
				BoxesPropertiesPageWidget* page = NULL;
				gint _tmp10_ = 0;
				BoxesMachine* _tmp11_ = NULL;
				BoxesPropertiesPageWidget* _tmp12_ = NULL;
				BoxesPropertiesPageWidget* _tmp13_ = NULL;
				gboolean _tmp14_ = FALSE;
				GtkLabel* label = NULL;
				BoxesPropertiesPageWidget* _tmp15_ = NULL;
				const gchar* _tmp16_ = NULL;
				const gchar* _tmp17_ = NULL;
				GtkLabel* _tmp18_ = NULL;
				BoxesPropertiesPageWidget* _tmp19_ = NULL;
				GtkLabel* _tmp20_ = NULL;
				gint _tmp21_ = 0;
				gint _tmp22_ = 0;
				gchar* _tmp23_ = NULL;
				gchar* _tmp24_ = NULL;
				gchar* _tmp25_ = NULL;
				gchar* _tmp26_ = NULL;
				BoxesPropertiesPageWidget* _tmp27_ = NULL;
				BoxesPropertiesPageWidget* _tmp28_ = NULL;
				BoxesPropertiesPageWidget* _tmp29_ = NULL;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				if (!_tmp7_) {
#line 374 "properties.c"
					gint _tmp8_ = 0;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp8_ = i;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					i = _tmp8_ + 1;
#line 380 "properties.c"
				}
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp7_ = FALSE;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp9_ = i;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				if (!(_tmp9_ < ((gint) BOXES_PROPERTIES_PAGE_LAST))) {
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					break;
#line 390 "properties.c"
				}
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp10_ = i;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp11_ = machine;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp12_ = boxes_properties_page_widget_new (_tmp10_, _tmp11_);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				g_object_ref_sink (_tmp12_);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				page = _tmp12_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp13_ = page;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp14_ = _tmp13_->empty;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				if (_tmp14_) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_g_object_unref0 (page);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					continue;
#line 412 "properties.c"
				}
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp15_ = page;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp16_ = gtk_widget_get_name ((GtkWidget*) _tmp15_);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp17_ = _tmp16_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp18_ = (GtkLabel*) gtk_label_new (_tmp17_);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				g_object_ref_sink (_tmp18_);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				label = _tmp18_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp19_ = page;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp20_ = label;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp21_ = i;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				gtk_notebook_insert_page ((GtkNotebook*) self, (GtkWidget*) _tmp19_, (GtkWidget*) _tmp20_, _tmp21_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp22_ = i;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp23_ = g_strdup_printf ("%i", _tmp22_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp24_ = _tmp23_;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp25_ = g_strconcat ("boxes-property-", _tmp24_, NULL);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp26_ = _tmp25_;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp27_ = page;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp28_ = _g_object_ref0 (_tmp27_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				g_object_set_data_full ((GObject*) self, _tmp26_, _tmp28_, g_object_unref);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_free0 (_tmp26_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_free0 (_tmp24_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp29_ = page;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				g_signal_connect_object (_tmp29_, "refresh-properties", (GCallback) ______lambda90__boxes_properties_page_widget_refresh_properties, self, 0);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_object_unref0 (label);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_object_unref0 (page);
#line 462 "properties.c"
			}
		}
	}
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_set ((GtkNotebook*) self, "page", (gint) BOXES_PROPERTIES_PAGE_GENERAL, NULL);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (machine);
#line 470 "properties.c"
}


static gboolean _boxes_properties_on_key_pressed_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self) {
	gboolean result;
	result = boxes_properties_on_key_pressed ((BoxesProperties*) self, _sender, event);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return result;
#line 479 "properties.c"
}


void boxes_properties_setup_ui (BoxesProperties* self, BoxesAppWindow* window, BoxesPropertiesWindow* dialog) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (window != NULL);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (dialog != NULL);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = window;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->window);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->window = _tmp1_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_signal_connect_object ((GtkWidget*) self, "key-press-event", (GCallback) _boxes_properties_on_key_pressed_gtk_widget_key_press_event, self, 0);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 504 "properties.c"
}


static Block73Data* block73_data_ref (Block73Data* _data73_) {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_atomic_int_inc (&_data73_->_ref_count_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return _data73_;
#line 513 "properties.c"
}


static void block73_data_unref (void * _userdata_) {
	Block73Data* _data73_;
	_data73_ = (Block73Data*) _userdata_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (g_atomic_int_dec_and_test (&_data73_->_ref_count_)) {
#line 522 "properties.c"
		BoxesProperties* self;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		self = _data73_->self;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (_data73_->machine);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (self);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_slice_free (Block73Data, _data73_);
#line 532 "properties.c"
	}
}


static void _____lambda91_ (Block73Data* _data73_) {
	BoxesProperties* self;
	BoxesMachine* _tmp0_ = NULL;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = _data73_->self;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = _data73_->machine;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_machine_restart (_tmp0_);
#line 546 "properties.c"
}


static void ______lambda91__boxes_notification_ok_func (gpointer self) {
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_____lambda91_ (self);
#line 553 "properties.c"
}


static void boxes_properties_ui_state_changed (BoxesProperties* self) {
	gulong _tmp0_ = 0UL;
	BoxesUIState _tmp5_ = 0;
	BoxesUIState _tmp6_ = 0;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->stats_id;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp0_ != ((gulong) 0)) {
#line 567 "properties.c"
		BoxesAppWindow* _tmp1_ = NULL;
		BoxesCollectionItem* _tmp2_ = NULL;
		BoxesCollectionItem* _tmp3_ = NULL;
		gulong _tmp4_ = 0UL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp1_ = self->priv->window;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp2_ = boxes_app_window_get_current_item (_tmp1_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp3_ = _tmp2_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp4_ = self->priv->stats_id;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_signal_handler_disconnect ((GObject*) _tmp3_, _tmp4_);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		self->priv->stats_id = (gulong) 0;
#line 584 "properties.c"
	}
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = _tmp5_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp6_ == BOXES_UI_STATE_PROPERTIES) {
#line 592 "properties.c"
		gboolean _tmp7_ = FALSE;
		BoxesUIState _tmp8_ = 0;
		BoxesUIState _tmp9_ = 0;
		BoxesAppWindow* _tmp13_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp8_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp9_ = _tmp8_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		if (_tmp9_ == BOXES_UI_STATE_DISPLAY) {
#line 603 "properties.c"
			BoxesAppWindow* _tmp10_ = NULL;
			gboolean _tmp11_ = FALSE;
			gboolean _tmp12_ = FALSE;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp10_ = self->priv->window;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp11_ = boxes_app_window_get_fullscreened (_tmp10_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp12_ = _tmp11_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp7_ = _tmp12_;
#line 615 "properties.c"
		} else {
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp7_ = FALSE;
#line 619 "properties.c"
		}
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		self->priv->restore_fullscreen = _tmp7_;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp13_ = self->priv->window;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_app_window_set_fullscreened (_tmp13_, FALSE);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_properties_populate (self);
#line 629 "properties.c"
	} else {
		BoxesUIState _tmp14_ = 0;
		BoxesUIState _tmp15_ = 0;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp14_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp15_ = _tmp14_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		if (_tmp15_ == BOXES_UI_STATE_PROPERTIES) {
#line 639 "properties.c"
			Block73Data* _data73_;
			gboolean reboot_required = FALSE;
			BoxesAppWindow* _tmp31_ = NULL;
			BoxesCollectionItem* _tmp32_ = NULL;
			BoxesCollectionItem* _tmp33_ = NULL;
			BoxesMachine* _tmp34_ = NULL;
			gboolean _tmp35_ = FALSE;
			gboolean _tmp36_ = FALSE;
			gboolean _tmp56_ = FALSE;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data73_ = g_slice_new0 (Block73Data);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data73_->_ref_count_ = 1;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data73_->self = g_object_ref (self);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			reboot_required = FALSE;
#line 657 "properties.c"
			{
				gint i = 0;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				i = 0;
#line 662 "properties.c"
				{
					gboolean _tmp16_ = FALSE;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp16_ = TRUE;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					while (TRUE) {
#line 669 "properties.c"
						gint _tmp18_ = 0;
						BoxesPropertiesPageWidget* page = NULL;
						gint _tmp19_ = 0;
						gchar* _tmp20_ = NULL;
						gchar* _tmp21_ = NULL;
						gchar* _tmp22_ = NULL;
						gchar* _tmp23_ = NULL;
						gconstpointer _tmp24_ = NULL;
						BoxesPropertiesPageWidget* _tmp25_ = NULL;
						BoxesPropertiesPageWidget* _tmp26_ = NULL;
						BoxesPropertiesPageWidget* _tmp27_ = NULL;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						if (!_tmp16_) {
#line 683 "properties.c"
							gint _tmp17_ = 0;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
							_tmp17_ = i;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
							i = _tmp17_ + 1;
#line 689 "properties.c"
						}
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp16_ = FALSE;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp18_ = i;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						if (!(_tmp18_ < ((gint) BOXES_PROPERTIES_PAGE_LAST))) {
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
							break;
#line 699 "properties.c"
						}
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp19_ = i;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp20_ = g_strdup_printf ("%i", _tmp19_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp21_ = _tmp20_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp22_ = g_strconcat ("boxes-property-", _tmp21_, NULL);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp23_ = _tmp22_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp24_ = g_object_get_data ((GObject*) self, _tmp23_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp25_ = _g_object_ref0 ((BoxesPropertiesPageWidget*) _tmp24_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp26_ = _tmp25_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_free0 (_tmp23_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_free0 (_tmp21_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						page = _tmp26_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp27_ = page;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						if (_tmp27_ != NULL) {
#line 727 "properties.c"
							gboolean _tmp28_ = FALSE;
							BoxesPropertiesPageWidget* _tmp29_ = NULL;
							gboolean _tmp30_ = FALSE;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
							_tmp28_ = reboot_required;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
							_tmp29_ = page;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
							_tmp30_ = boxes_properties_page_widget_flush_changes (_tmp29_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
							reboot_required = _tmp28_ | _tmp30_;
#line 739 "properties.c"
						}
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_object_unref0 (page);
#line 743 "properties.c"
					}
				}
			}
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp31_ = self->priv->window;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp32_ = boxes_app_window_get_current_item (_tmp31_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp33_ = _tmp32_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp34_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp33_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp33_) : NULL);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data73_->machine = _tmp34_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp36_ = reboot_required;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			if (_tmp36_) {
#line 761 "properties.c"
				gboolean _tmp37_ = FALSE;
				BoxesMachine* _tmp38_ = NULL;
				gboolean _tmp39_ = FALSE;
				gboolean _tmp40_ = FALSE;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp38_ = _data73_->machine;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp39_ = boxes_machine_get_is_on (_tmp38_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp40_ = _tmp39_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				if (_tmp40_) {
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp37_ = TRUE;
#line 776 "properties.c"
				} else {
					BoxesMachine* _tmp41_ = NULL;
					BoxesMachineMachineState _tmp42_ = 0;
					BoxesMachineMachineState _tmp43_ = 0;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp41_ = _data73_->machine;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp42_ = boxes_machine_get_state (_tmp41_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp43_ = _tmp42_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp37_ = _tmp43_ == BOXES_MACHINE_MACHINE_STATE_SAVED;
#line 789 "properties.c"
				}
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp35_ = _tmp37_;
#line 793 "properties.c"
			} else {
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp35_ = FALSE;
#line 797 "properties.c"
			}
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			if (_tmp35_) {
#line 801 "properties.c"
				gchar* message = NULL;
				const gchar* _tmp44_ = NULL;
				BoxesMachine* _tmp45_ = NULL;
				const gchar* _tmp46_ = NULL;
				const gchar* _tmp47_ = NULL;
				gchar* _tmp48_ = NULL;
				BoxesAppWindow* _tmp49_ = NULL;
				BoxesNotificationbar* _tmp50_ = NULL;
				BoxesNotificationbar* _tmp51_ = NULL;
				const gchar* _tmp52_ = NULL;
				const gchar* _tmp53_ = NULL;
				GdNotification* _tmp54_ = NULL;
				GdNotification* _tmp55_ = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp44_ = _ ("Changes require restart of '%s'.");
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp45_ = _data73_->machine;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp46_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp45_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp47_ = _tmp46_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp48_ = g_strdup_printf (_tmp44_, _tmp47_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				message = _tmp48_;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp49_ = self->priv->window;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp50_ = boxes_app_window_get_notificationbar (_tmp49_);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp51_ = _tmp50_;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp52_ = message;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp53_ = _ ("_Restart");
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp54_ = boxes_notificationbar_display_for_action (_tmp51_, _tmp52_, _tmp53_, ______lambda91__boxes_notification_ok_func, block73_data_ref (_data73_), block73_data_unref, NULL, NULL, NULL, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp55_ = _tmp54_;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_object_unref0 (_tmp55_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_free0 (message);
#line 845 "properties.c"
			}
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp56_ = self->priv->restore_fullscreen;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			if (_tmp56_) {
#line 851 "properties.c"
				BoxesAppWindow* _tmp57_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp57_ = self->priv->window;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				boxes_app_window_set_fullscreened (_tmp57_, TRUE);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				self->priv->restore_fullscreen = FALSE;
#line 859 "properties.c"
			}
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			block73_data_unref (_data73_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data73_ = NULL;
#line 865 "properties.c"
		}
	}
}


static gboolean boxes_properties_on_key_pressed (BoxesProperties* self, GtkWidget* widget, GdkEventKey* event) {
	gboolean result = FALSE;
	GdkModifierType default_modifiers = 0;
	GdkModifierType _tmp0_ = 0;
	gboolean _tmp1_ = FALSE;
	GdkEventKey* _tmp2_ = NULL;
	guint _tmp3_ = 0U;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_val_if_fail (widget != NULL, FALSE);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = gtk_accelerator_get_default_mod_mask ();
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	default_modifiers = _tmp0_;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = event;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = _tmp2_->keyval;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp3_ == ((guint) GDK_KEY_Left)) {
#line 894 "properties.c"
		GdkEventKey* _tmp4_ = NULL;
		GdkModifierType _tmp5_ = 0;
		GdkModifierType _tmp6_ = 0;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp4_ = event;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp5_ = _tmp4_->state;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp6_ = default_modifiers;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp1_ = (_tmp5_ & _tmp6_) == GDK_MOD1_MASK;
#line 906 "properties.c"
	} else {
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp1_ = FALSE;
#line 910 "properties.c"
	}
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp1_) {
#line 914 "properties.c"
		gint _tmp7_ = 0;
		gint _tmp8_ = 0;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_object_get ((GtkNotebook*) self, "page", &_tmp7_, NULL);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp8_ = _tmp7_;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		if (_tmp8_ > ((gint) BOXES_PROPERTIES_PAGE_GENERAL)) {
#line 923 "properties.c"
			gint _tmp9_ = 0;
			gint _tmp10_ = 0;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			g_object_get ((GtkNotebook*) self, "page", &_tmp9_, NULL);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp10_ = _tmp9_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			g_object_set ((GtkNotebook*) self, "page", _tmp10_ - 1, NULL);
#line 932 "properties.c"
		}
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		result = TRUE;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		return result;
#line 938 "properties.c"
	} else {
		gboolean _tmp11_ = FALSE;
		GdkEventKey* _tmp12_ = NULL;
		guint _tmp13_ = 0U;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp12_ = event;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp13_ = _tmp12_->keyval;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		if (_tmp13_ == ((guint) GDK_KEY_Right)) {
#line 949 "properties.c"
			GdkEventKey* _tmp14_ = NULL;
			GdkModifierType _tmp15_ = 0;
			GdkModifierType _tmp16_ = 0;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp14_ = event;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp15_ = _tmp14_->state;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp16_ = default_modifiers;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp11_ = (_tmp15_ & _tmp16_) == GDK_MOD1_MASK;
#line 961 "properties.c"
		} else {
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp11_ = FALSE;
#line 965 "properties.c"
		}
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		if (_tmp11_) {
#line 969 "properties.c"
			gint _tmp17_ = 0;
			gint _tmp18_ = 0;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			g_object_get ((GtkNotebook*) self, "page", &_tmp17_, NULL);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp18_ = _tmp17_;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			if (_tmp18_ < ((gint) BOXES_PROPERTIES_PAGE_LAST)) {
#line 978 "properties.c"
				gint _tmp19_ = 0;
				gint _tmp20_ = 0;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				g_object_get ((GtkNotebook*) self, "page", &_tmp19_, NULL);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp20_ = _tmp19_;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				g_object_set ((GtkNotebook*) self, "page", _tmp20_ + 1, NULL);
#line 987 "properties.c"
			}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			result = TRUE;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			return result;
#line 993 "properties.c"
		}
	}
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	result = FALSE;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return result;
#line 1000 "properties.c"
}


BoxesProperties* boxes_properties_construct (GType object_type) {
	BoxesProperties * self = NULL;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) g_object_new (object_type, NULL);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return self;
#line 1010 "properties.c"
}


BoxesProperties* boxes_properties_new (void) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return boxes_properties_construct (BOXES_TYPE_PROPERTIES);
#line 1017 "properties.c"
}


static BoxesUIState boxes_properties_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesProperties* self;
	BoxesUIState _tmp0_ = 0;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) base;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	result = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return result;
#line 1033 "properties.c"
}


static void boxes_properties_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesProperties* self;
	BoxesUIState _tmp0_ = 0;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) base;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = value;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->_previous_ui_state = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_notify ((GObject *) self, "previous-ui-state");
#line 1048 "properties.c"
}


static BoxesUIState boxes_properties_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesProperties* self;
	BoxesUIState _tmp0_ = 0;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) base;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->_ui_state;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	result = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return result;
#line 1064 "properties.c"
}


static void boxes_properties_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesProperties* self;
	BoxesUIState _tmp0_ = 0;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) base;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = value;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->_ui_state = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_notify ((GObject *) self, "ui-state");
#line 1079 "properties.c"
}


static void _boxes_properties_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_ui_state_changed ((BoxesProperties*) self);
#line 1086 "properties.c"
}


static GObject * boxes_properties_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesProperties * self;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	parent_class = G_OBJECT_CLASS (boxes_properties_parent_class);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_PROPERTIES, BoxesProperties);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_signal_connect_object ((GObject*) self, "notify::ui-state", (GCallback) _boxes_properties_ui_state_changed_g_object_notify, self, 0);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return obj;
#line 1104 "properties.c"
}


static void boxes_properties_class_init (BoxesPropertiesClass * klass) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_parent_class = g_type_class_peek_parent (klass);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_type_class_add_private (klass, sizeof (BoxesPropertiesPrivate));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_properties_get_property;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_properties_set_property;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_properties_constructor;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_properties_finalize;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTIES_PREVIOUS_UI_STATE, g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTIES_UI_STATE, g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1125 "properties.c"
}


static void boxes_properties_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	iface->get_previous_ui_state = boxes_properties_real_get_previous_ui_state;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	iface->set_previous_ui_state = boxes_properties_real_set_previous_ui_state;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	iface->get_ui_state = boxes_properties_real_get_ui_state;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	iface->set_ui_state = boxes_properties_real_set_ui_state;
#line 1140 "properties.c"
}


static void boxes_properties_instance_init (BoxesProperties * self) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv = BOXES_PROPERTIES_GET_PRIVATE (self);
#line 1147 "properties.c"
}


static void boxes_properties_finalize (GObject* obj) {
	BoxesProperties * self;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_PROPERTIES, BoxesProperties);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->window);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (boxes_properties_parent_class)->finalize (obj);
#line 1159 "properties.c"
}


GType boxes_properties_get_type (void) {
	static volatile gsize boxes_properties_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesPropertiesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_properties_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesProperties), 0, (GInstanceInitFunc) boxes_properties_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_properties_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_properties_type_id;
		boxes_properties_type_id = g_type_register_static (gtk_notebook_get_type (), "BoxesProperties", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_properties_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_properties_type_id__volatile, boxes_properties_type_id);
	}
	return boxes_properties_type_id__volatile;
}


static void _vala_boxes_properties_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesProperties * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_PROPERTIES, BoxesProperties);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	switch (property_id) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PREVIOUS_UI_STATE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_UI_STATE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 1194 "properties.c"
		default:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 1200 "properties.c"
	}
}


static void _vala_boxes_properties_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesProperties * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_PROPERTIES, BoxesProperties);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	switch (property_id) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PREVIOUS_UI_STATE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_UI_STATE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 1222 "properties.c"
		default:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 1228 "properties.c"
	}
}



